@@ -19,12 +19,8 @@ class CountryError(Exception):
 
 
 class Country:
-    """Country class with various methods to help with countries and regions. Uses OCHA countries feed which
-    supplies data in form:
-    ::
-        ID,HRinfo ID,RW ID,m49 numerical code,FTS API ID,Appears in UNTERM list,Appears in DGACM list,ISO 3166-1 Alpha 2-Codes,ISO 3166-1 Alpha 3-Codes,x Alpha2 codes,x Alpha3 codes,Preferred Term,m49 Alt Term,ISO Alt Term,UNTERM Alt Term,FTS Alt Term,HRinfo Alt Term,RW Short Name,RW API Alt Term,English Short,French Short,Spanish Short,Russian Short,Chinese Short,Arabic Short,Admin Level,Latitude,Longitude,Region Code,Region Name,Sub-region Code,Sub-region Name,Intermediate Region Code,Intermediate Region Name,Regex,Concatenation
-        #meta +id,#country +code +v_hrinfo_country,#country +code +v_reliefweb,#country +code +num +v_m49,#country +code +v_fts,,,#country +code +v_iso2,#country +code +v_iso3,,,#country +name +preferred,#country +name +alt +v_m49,#country +name +alt +v_iso,#country +name +alt +v_unterm,#country +name +alt +v_fts,#country +name +alt +v_hrinfo_country,#country +name +short +v_reliefweb,#country +name +alt +v_reliefweb,#country +name +i_en +alt +v_unterm,#country +name +i_fr +alt +v_unterm,#country +name +i_es +alt +v_unterm,#country +name +i_ru +alt +v_unterm,#country +name +i_zh +alt +v_unterm,#country +name +i_ar +alt +v_unterm,#geo +admin_level,#geo +lat,#geo +lon,#region +main +code,#region +main +name +preferred,#region +sub +code,#region +sub +name +preferred,#region +intermediate +code,#region +intermediate +name +preferred,#country +regex,
-        1,181,13,4,1,Y,Y,AF,AFG,,,Afghanistan,,,,,,,,Afghanistan,Afghanistan (l') [masc.],Afganistán (el),Афганистан,阿富汗,أفغانستان,0,33.83147477,66.02621828,142,Asia,34,Southern Asia,,,afghan,
+    """Country class with various methods to help with mapping between country and
+    region names and codes. Uses OCHA's countries and territories feed.
     """
 
     abbreviations = {
@@ -40,7 +36,14 @@ class Country:
         "W.": "WEST",
         "K.": "KINGDOM",
     }
-    major_differentiators = ["DEMOCRATIC", "NORTH", "SOUTH", "EAST", "WEST", "STATES"]
+    major_differentiators = [
+        "DEMOCRATIC",
+        "NORTH",
+        "SOUTH",
+        "EAST",
+        "WEST",
+        "STATES",
+    ]
     multiple_abbreviations = {
         "FED.": ["FEDERATION", "FEDERAL", "FEDERATED"],
         "ISL.": ["ISLAND", "ISLANDS"],
@@ -103,7 +106,9 @@ class Country:
         )
         regionname = hxlcountry.get("#region+main+name+preferred")
         sub_regionname = hxlcountry.get("#region+name+preferred+sub")
-        intermediate_regionname = hxlcountry.get("#region+intermediate+name+preferred")
+        intermediate_regionname = hxlcountry.get(
+            "#region+intermediate+name+preferred"
+        )
         regionid = hxlcountry.get("#region+code+main")
         if regionid:
             regionid = int(regionid)
@@ -125,15 +130,21 @@ class Country:
         if regionname:
             add_country_to_set("regioncodes2countries", regionid, iso3)
             cls._countriesdata["regioncodes2names"][regionid] = regionname
-            cls._countriesdata["regionnames2codes"][regionname.upper()] = regionid
+            cls._countriesdata["regionnames2codes"][
+                regionname.upper()
+            ] = regionid
         if sub_regionname:
             add_country_to_set("regioncodes2countries", sub_regionid, iso3)
-            cls._countriesdata["regioncodes2names"][sub_regionid] = sub_regionname
+            cls._countriesdata["regioncodes2names"][
+                sub_regionid
+            ] = sub_regionname
             cls._countriesdata["regionnames2codes"][
                 sub_regionname.upper()
             ] = sub_regionid
         if intermediate_regionname:
-            add_country_to_set("regioncodes2countries", intermediate_regionid, iso3)
+            add_country_to_set(
+                "regioncodes2countries", intermediate_regionid, iso3
+            )
             cls._countriesdata["regioncodes2names"][
                 intermediate_regionid
             ] = intermediate_regionname
@@ -167,7 +178,9 @@ class Country:
         cls._countriesdata["currencies"] = dict()
 
         for key, value in cls._country_name_mappings.items():
-            cls._countriesdata["countrynames2iso3"][key.upper()] = value.upper()
+            cls._countriesdata["countrynames2iso3"][
+                key.upper()
+            ] = value.upper()
 
         for country in countries:
             iso3 = country.get("#country+code+v_iso3")
@@ -191,7 +204,7 @@ class Country:
         use_live: bool = True,
         country_name_overrides: Dict = None,
         country_name_mappings: Dict = None,
-    ) -> List[Dict[str,Dict]]:
+    ) -> List[Dict[str, Dict]]:
         """
         Read countries data from OCHA countries feed (falling back to file)
 
@@ -274,7 +287,7 @@ class Country:
         iso3: str,
         use_live: bool = True,
         exception: Optional[ExceptionUpperBound] = None,
-    ) -> Optional[Dict[str,str]]:
+    ) -> Optional[Dict[str, str]]:
         """Get country information from ISO3 code
 
         Args:
@@ -410,7 +423,7 @@ class Country:
         iso2: str,
         use_live: bool = True,
         exception: Optional[ExceptionUpperBound] = None,
-    ) -> Optional[Dict[str,str]]:
+    ) -> Optional[Dict[str, str]]:
         """Get country name from ISO2 code
 
         Args:
@@ -421,7 +434,9 @@ class Country:
         Returns:
             Optional[Dict[str,str]]: Country information
         """
-        iso3 = cls.get_iso3_from_iso2(iso2, use_live=use_live, exception=exception)
+        iso3 = cls.get_iso3_from_iso2(
+            iso2, use_live=use_live, exception=exception
+        )
         if iso3 is not None:
             return cls.get_country_info_from_iso3(
                 iso3, use_live=use_live, exception=exception
@@ -447,7 +462,9 @@ class Country:
         Returns:
             Optional[str]: Country name
         """
-        iso3 = cls.get_iso3_from_iso2(iso2, use_live=use_live, exception=exception)
+        iso3 = cls.get_iso3_from_iso2(
+            iso2, use_live=use_live, exception=exception
+        )
         if iso3 is not None:
             return cls.get_country_name_from_iso3(
                 iso3, exception=exception, shortname=shortname
@@ -471,7 +488,9 @@ class Country:
         Returns:
             Optional[str]: Currency
         """
-        iso3 = cls.get_iso3_from_iso2(iso2, use_live=use_live, exception=exception)
+        iso3 = cls.get_iso3_from_iso2(
+            iso2, use_live=use_live, exception=exception
+        )
         if iso3 is not None:
             return cls.get_currency_from_iso3(
                 iso3, use_live=use_live, exception=exception
@@ -536,7 +555,7 @@ class Country:
         m49: int,
         use_live: bool = True,
         exception: Optional[ExceptionUpperBound] = None,
-    ) -> Optional[Dict[str,str]]:
+    ) -> Optional[Dict[str, str]]:
         """Get country name from M49 code
 
         Args:
@@ -547,7 +566,9 @@ class Country:
         Returns:
             Optional[Dict[str,str]]: Country information
         """
-        iso3 = cls.get_iso3_from_m49(m49, use_live=use_live, exception=exception)
+        iso3 = cls.get_iso3_from_m49(
+            m49, use_live=use_live, exception=exception
+        )
         if iso3 is not None:
             return cls.get_country_info_from_iso3(iso3, exception=exception)
         return None
@@ -571,7 +592,9 @@ class Country:
         Returns:
             Optional[str]: Country name
         """
-        iso3 = cls.get_iso3_from_m49(m49, use_live=use_live, exception=exception)
+        iso3 = cls.get_iso3_from_m49(
+            m49, use_live=use_live, exception=exception
+        )
         if iso3 is not None:
             return cls.get_country_name_from_iso3(
                 iso3, exception=exception, shortname=shortname
@@ -595,7 +618,9 @@ class Country:
         Returns:
             Optional[str]: Currency
         """
-        iso3 = cls.get_iso3_from_m49(m49, use_live=use_live, exception=exception)
+        iso3 = cls.get_iso3_from_m49(
+            m49, use_live=use_live, exception=exception
+        )
         if iso3 is not None:
             return cls.get_currency_from_iso3(
                 iso3, use_live=use_live, exception=exception
@@ -614,7 +639,11 @@ class Country:
         """
 
         def replace_ensure_space(word, replace, replacement):
-            return word.replace(replace, f"{replacement} ").replace("  ", " ").strip()
+            return (
+                word.replace(replace, f"{replacement} ")
+                .replace("  ", " ")
+                .strip()
+            )
 
         countryupper = country.upper()
         for abbreviation in cls.abbreviations:
@@ -626,7 +655,9 @@ class Country:
             if abbreviation in countryupper:
                 for expanded in cls.multiple_abbreviations[abbreviation]:
                     candidates.append(
-                        replace_ensure_space(countryupper, abbreviation, expanded)
+                        replace_ensure_space(
+                            countryupper, abbreviation, expanded
+                        )
                     )
         return candidates
 
@@ -654,7 +685,10 @@ class Country:
         for simplification1, simplification2 in cls.abbreviations.items():
             countryupper = countryupper.replace(simplification1, "")
             remove.append(simplification2)
-        for simplification1, simplifications in cls.multiple_abbreviations.items():
+        for (
+            simplification1,
+            simplifications,
+        ) in cls.multiple_abbreviations.items():
             countryupper = countryupper.replace(simplification1, "")
             for simplification2 in simplifications:
                 remove.append(simplification2)
@@ -765,7 +799,9 @@ class Country:
         matches = set()
         for countryname in sorted(countriesdata["countrynames2iso3"]):
             for candidate in expanded_country_candidates:
-                simplified_country, removed_words = cls.simplify_countryname(candidate)
+                simplified_country, removed_words = cls.simplify_countryname(
+                    candidate
+                )
                 if simplified_country in countryname:
                     words = get_words_in_sentence(countryname)
                     new_match_strength = remove_matching_from_list(
